@@ -5,5 +5,6 @@ import numpy
 
 setup(
     cmdclass = {'build_ext': build_ext},
-    ext_modules = [Extension("Z_shooting", ["Z_shooting.pyx"], include_dirs=[numpy.get_include()])]
-)
\ No newline at end of file
+    ext_modules = [Extension("Z_shooting", ["Z_shooting.pyx"],)],
+    include_dirs=[numpy.get_include(),],
+)
